==> openshift-model-machine-5.10.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/ObjectMetaFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.OwnerReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ObjectMetaFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<A>{
  public ObjectMetaFluentImpl() {
  }
  public ObjectMetaFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta instance) {
    this.withAnnotations(instance.getAnnotations()); 
    this.withGenerateName(instance.getGenerateName()); 
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withOwnerReferences(instance.getOwnerReferences()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,java.lang.String> annotations;
  private java.lang.String generateName;
  private java.util.Map<java.lang.String,java.lang.String> labels;
  private java.lang.String name;
  private java.lang.String namespace;
  private java.util.List<io.fabric8.kubernetes.api.model.OwnerReference> ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAnnotations(java.lang.String key,java.lang.String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null && map != null) { this.annotations = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(java.lang.String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(java.util.Map<java.lang.String,java.lang.String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(annotations);} return (A) this;
  }
  public java.lang.Boolean hasAnnotations() {
    return this.annotations != null;
  }
  public java.lang.String getGenerateName() {
    return this.generateName;
  }
  public A withGenerateName(java.lang.String generateName) {
    this.generateName=generateName; return (A) this;
  }
  public java.lang.Boolean hasGenerateName() {
    return this.generateName != null;
  }
  
  /**
   * Method is deprecated. use withGenerateName instead.
   */
  @java.lang.Deprecated
  public A withNewGenerateName(java.lang.String arg0) {
    return (A)withGenerateName(new String(arg0));
  }
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public A addToOwnerReferences(java.lang.Integer index,io.fabric8.kubernetes.api.model.OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    this.ownerReferences.add(index, item);
    return (A)this;
  }
  public A setToOwnerReferences(java.lang.Integer index,io.fabric8.kubernetes.api.model.OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    this.ownerReferences.set(index, item); return (A)this;
  }
  public A addToOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A addAllToOwnerReferences(java.util.Collection<io.fabric8.kubernetes.api.model.OwnerReference> items) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A removeFromOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public A removeAllFromOwnerReferences(java.util.Collection<io.fabric8.kubernetes.api.model.OwnerReference> items) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public java.util.List<io.fabric8.kubernetes.api.model.OwnerReference> getOwnerReferences() {
    return this.ownerReferences;
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getOwnerReference(java.lang.Integer index) {
    return this.ownerReferences.get(index);
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getFirstOwnerReference() {
    return this.ownerReferences.get(0);
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getLastOwnerReference() {
    return this.ownerReferences.get(ownerReferences.size() - 1);
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getMatchingOwnerReference(java.util.function.Predicate<io.fabric8.kubernetes.api.model.OwnerReference> predicate) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item: ownerReferences) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingOwnerReference(java.util.function.Predicate<io.fabric8.kubernetes.api.model.OwnerReference> predicate) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item: ownerReferences) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOwnerReferences(java.util.List<io.fabric8.kubernetes.api.model.OwnerReference> ownerReferences) {
    if (ownerReferences != null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>(); for (io.fabric8.kubernetes.api.model.OwnerReference item : ownerReferences){this.addToOwnerReferences(item);}} else { this.ownerReferences = null;} return (A) this;
  }
  public A withOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... ownerReferences) {
    if (this.ownerReferences != null) {this.ownerReferences.clear();}
    if (ownerReferences != null) {for (io.fabric8.kubernetes.api.model.OwnerReference item :ownerReferences){ this.addToOwnerReferences(item);}} return (A) this;
  }
  public java.lang.Boolean hasOwnerReferences() {
    return ownerReferences != null && !ownerReferences.isEmpty();
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObjectMetaFluentImpl that = (ObjectMetaFluentImpl) o;
    if (annotations != null ? !annotations.equals(that.annotations) :that.annotations != null) return false;
    if (generateName != null ? !generateName.equals(that.generateName) :that.generateName != null) return false;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (ownerReferences != null ? !ownerReferences.equals(that.ownerReferences) :that.ownerReferences != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  generateName,  labels,  name,  namespace,  ownerReferences,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-machine-5.12.0-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/ObjectMetaFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.OwnerReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ObjectMetaFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.ObjectMetaFluent<A>{
  public ObjectMetaFluentImpl() {
  }
  public ObjectMetaFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.ObjectMeta instance) {
    this.withAnnotations(instance.getAnnotations()); 
    this.withGenerateName(instance.getGenerateName()); 
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withOwnerReferences(instance.getOwnerReferences()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,java.lang.String> annotations;
  private java.lang.String generateName;
  private java.util.Map<java.lang.String,java.lang.String> labels;
  private java.lang.String name;
  private java.lang.String namespace;
  private java.util.List<io.fabric8.kubernetes.api.model.OwnerReference> ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAnnotations(java.lang.String key,java.lang.String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null && map != null) { this.annotations = new java.util.LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(java.lang.String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(java.util.Map<java.lang.String,java.lang.String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new java.util.LinkedHashMap(annotations);} return (A) this;
  }
  public java.lang.Boolean hasAnnotations() {
    return this.annotations != null;
  }
  public java.lang.String getGenerateName() {
    return this.generateName;
  }
  public A withGenerateName(java.lang.String generateName) {
    this.generateName=generateName; return (A) this;
  }
  public java.lang.Boolean hasGenerateName() {
    return this.generateName != null;
  }
  
  /**
   * Method is deprecated. use withGenerateName instead.
   */
  @java.lang.Deprecated
  public A withNewGenerateName(java.lang.String arg0) {
    return (A)withGenerateName(new String(arg0));
  }
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public A addToOwnerReferences(java.lang.Integer index,io.fabric8.kubernetes.api.model.OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    this.ownerReferences.add(index, item);
    return (A)this;
  }
  public A setToOwnerReferences(java.lang.Integer index,io.fabric8.kubernetes.api.model.OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    this.ownerReferences.set(index, item); return (A)this;
  }
  public A addToOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A addAllToOwnerReferences(java.util.Collection<io.fabric8.kubernetes.api.model.OwnerReference> items) {
    if (this.ownerReferences == null) {this.ownerReferences = new java.util.ArrayList<io.fabric8.kubernetes.api.model.OwnerReference>();}
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A removeFromOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public A removeAllFromOwnerReferences(java.util.Collection<io.fabric8.kubernetes.api.model.OwnerReference> items) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public java.util.List<io.fabric8.kubernetes.api.model.OwnerReference> getOwnerReferences() {
    return this.ownerReferences;
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getOwnerReference(java.lang.Integer index) {
    return this.ownerReferences.get(index);
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getFirstOwnerReference() {
    return this.ownerReferences.get(0);
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getLastOwnerReference() {
    return this.ownerReferences.get(ownerReferences.size() - 1);
  }
  public io.fabric8.kubernetes.api.model.OwnerReference getMatchingOwnerReference(java.util.function.Predicate<io.fabric8.kubernetes.api.model.OwnerReference> predicate) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item: ownerReferences) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingOwnerReference(java.util.function.Predicate<io.fabric8.kubernetes.api.model.OwnerReference> predicate) {
    for (io.fabric8.kubernetes.api.model.OwnerReference item: ownerReferences) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOwnerReferences(java.util.List<io.fabric8.kubernetes.api.model.OwnerReference> ownerReferences) {
    if (ownerReferences != null) {this.ownerReferences = new java.util.ArrayList(); for (io.fabric8.kubernetes.api.model.OwnerReference item : ownerReferences){this.addToOwnerReferences(item);}} else { this.ownerReferences = null;} return (A) this;
  }
  public A withOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... ownerReferences) {
    if (this.ownerReferences != null) {this.ownerReferences.clear();}
    if (ownerReferences != null) {for (io.fabric8.kubernetes.api.model.OwnerReference item :ownerReferences){ this.addToOwnerReferences(item);}} return (A) this;
  }
  public java.lang.Boolean hasOwnerReferences() {
    return ownerReferences != null && !ownerReferences.isEmpty();
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObjectMetaFluentImpl that = (ObjectMetaFluentImpl) o;
    if (annotations != null ? !annotations.equals(that.annotations) :that.annotations != null) return false;
    if (generateName != null ? !generateName.equals(that.generateName) :that.generateName != null) return false;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (ownerReferences != null ? !ownerReferences.equals(that.ownerReferences) :that.ownerReferences != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  generateName,  labels,  name,  namespace,  ownerReferences,  additionalProperties,  super.hashCode());
  }
  
}
